@@ -39,7 +39,7 @@
  * AN ACTION OF CONTRACT, NEGLIGENCE OR OTHER TORTIOUS ACTION, ARISING
  * OUT OF OR IN CONNECTION WITH THE USE OR PERFORMANCE OF THIS SOFTWARE.
  *
- * $Id: util.h,v 1.25 2008/03/24 17:43:09 murch Exp $
+ * $Id: util.h,v 1.28 2010/06/28 12:06:44 brong Exp $
  *
  * Author: Chris Newman
  * Start Date: 4/6/93
@@ -48,6 +48,43 @@
 #ifndef INCLUDED_UTIL_H
 #define INCLUDED_UTIL_H
 
+#include <config.h>
+#include <sys/types.h>
+#include <limits.h>
+
+#define BIT32_MAX 4294967295U
+
+#if UINT_MAX == BIT32_MAX
+typedef unsigned int bit32;
+#elif ULONG_MAX == BIT32_MAX
+typedef unsigned long bit32;
+#elif USHRT_MAX == BIT32_MAX
+typedef unsigned short bit32;
+#else
+#error dont know what to use for bit32
+#endif
+
+#ifdef HAVE_LONG_LONG_INT
+typedef unsigned long long int bit64;
+typedef unsigned long long int modseq_t;
+#define MODSEQ_FMT "%llu"
+#define atomodseq_t(s) strtoull(s, NULL, 10)
+#else
+typedef unsigned long int modseq_t;
+#define MODSEQ_FMT "%lu"
+#define atomodseq_t(s) strtoul(s, NULL, 10)
+#endif
+
+#define Uisalnum(c) isalnum((int)((unsigned char)(c)))
+#define Uisalpha(c) isalpha((int)((unsigned char)(c)))
+#define Uisascii(c) isascii((int)((unsigned char)(c)))
+#define Uiscntrl(c) iscntrl((int)((unsigned char)(c)))
+#define Uisdigit(c) isdigit((int)((unsigned char)(c)))
+#define Uislower(c) islower((int)((unsigned char)(c)))
+#define Uisspace(c) isspace((int)((unsigned char)(c)))
+#define Uisupper(c) isupper((int)((unsigned char)(c)))
+#define Uisxdigit(c) isxdigit((int)((unsigned char)(c)))
+
 extern const unsigned char convert_to_lowercase[256];
 extern const unsigned char convert_to_uppercase[256];
 
@@ -116,5 +153,38 @@ extern int become_cyrus(void);
  */
 
 #define cyrus_isdigit(x) ((x) >= '0' && (x) <= '9')
+extern int parseint32(const char *p, const char **ptr, int32_t *res);
+extern int parseuint32(const char *p, const char **ptr, uint32_t *res);
+
+/* Timing related funcs/vars */
+extern void cmdtime_settimer(int enable);
+extern void cmdtime_starttimer();
+extern void cmdtime_endtimer(double * cmdtime, double * nettime);
+extern void cmdtime_netstart();
+extern void cmdtime_netend();
+
+
+#define BUF_CSTRING 1
+
+struct buf {
+    char *s;
+    unsigned len;
+    unsigned alloc;
+    int flags;
+};
+
+const char *buf_cstring(struct buf *buf);
+void buf_getmap(struct buf *buf, const char **base, int *len);
+unsigned buf_len(struct buf *buf);
+void buf_reset(struct buf *buf);
+void buf_setcstr(struct buf *buf, char *str);
+void buf_setmap(struct buf *buf, char *base, int len);
+void buf_copy(struct buf *dst, struct buf *src);
+void buf_append(struct buf *dst, struct buf *src);
+void buf_appendcstr(struct buf *buf, char *str);
+void buf_appendbit32(struct buf *buf, bit32 num);
+void buf_appendmap(struct buf *buf, char *base, int len);
+void buf_putc(struct buf *buf, char c);
+void buf_free(struct buf *buf);
 
 #endif /* INCLUDED_UTIL_H */
